@@ -206,8 +206,8 @@ def output_to_excel_file(
 def process_excel_file(
     input_file: "str | Path",
     output_file: "str | Path",
-    excel_definition_config: "str | None" = None,
-    sprint_schedule_config: "str | None" = None,
+    excel_definition_config: "str | Path | None" = None,
+    sprint_schedule_config: "str | Path | None" = None,
     over_write: bool = True,
 ):
     """
