@@ -18,7 +18,7 @@ class Priority(IntEnum):
             return "N/A"
         return self.name.capitalize()
 
-    def __lt__(self, __o: object) -> bool:
+    def __lt__(self, __o: "Priority") -> bool:
         l = -1
         if type(self.value) is tuple:
             l = self.value[0]
@@ -35,7 +35,7 @@ class Priority(IntEnum):
         else:
             return False
 
-    def __gt__(self, __o: object) -> bool:
+    def __gt__(self, __o: "Priority") -> bool:
         l = -1
         if type(self.value) is tuple:
             l = self.value[0]
@@ -52,7 +52,7 @@ class Priority(IntEnum):
         else:
             return False
 
-    def __le__(self, __o: object) -> bool:
+    def __le__(self, __o: "Priority") -> bool:
         l = -1
         if type(self.value) is tuple:
             l = self.value[0]
@@ -69,7 +69,24 @@ class Priority(IntEnum):
         else:
             return False
 
-    def __eq__(self, __o: object) -> bool:
+    def __ge__(self, __o: "Priority") -> bool:
+        l = -1
+        if type(self.value) is tuple:
+            l = self.value[0]
+        elif type(self.value) is int:
+            l = self.value
+        r = -1
+        if type(__o.value) is tuple:
+            r = __o.value[0]
+        elif type(__o.value) is int:
+            r = __o.value
+
+        if l >= r:
+            return True
+        else:
+            return False
+
+    def __eq__(self, __o: "Priority") -> bool:
         if self.value == __o.value:
             return True
         else:
@@ -81,15 +98,15 @@ def convert_to_priority(raw: Any) -> Priority:
         return Priority.NA
     if type(raw) is Priority:
         return raw
-    raw = str(raw).strip().upper()
-    if raw == "N/A":
+    value = str(raw).strip().upper()
+    if value == "N/A" or value == "NA":
         return Priority.NA
-    elif raw == "LOW":
+    elif value == "LOW":
         return Priority.LOW
-    elif raw == "MEDIUM":
+    elif value == "MEDIUM" or value == "MIDDLE":
         return Priority.MIDDLE
-    elif raw == "HIGH":
+    elif value == "HIGH":
         return Priority.HIGH
-    elif raw == "CRITICAL":
+    elif value == "CRITICAL":
         return Priority.CRITICAL
     return Priority.NA
